@@ -7,6 +7,6 @@ library(igraph)
 DNSL.betweenness <- function( df, first.node="V1", second.node="V2" ) {
   dup.graph <- dup.nodes.from.data.frame(df, first.node, second.node)
   betweenness <- betweenness(dup.graph)
-  original.nodes <- V(dup.graph)[ !grepl("'", V(dup.graph)$name) ]
+  original.nodes <- .original_graph_nodes(dup.graph)
   return( betweenness[ original.nodes ] )
 }
